@@ -1,7 +1,9 @@
 use std::{convert::TryFrom, env};
 
+use clap_generate::generators::{Bash, Elvish, Fish, PowerShell, Zsh};
 use miette::{GraphicalTheme, IntoDiagnostic, Result};
 use mit_commit_message_lints::{
+    console::style::print_completions,
     external::Git2,
     mit::{get_commit_coauthor_configuration, AuthorState},
 };
@@ -12,6 +14,7 @@ use crate::{
 };
 
 fn main() -> Result<()> {
+    miette::set_panic_hook();
     if env::var("DEBUG_PRETTY_ERRORS").is_ok() {
         miette::set_hook(Box::new(|_| {
             Box::new(
@@ -24,7 +27,22 @@ fn main() -> Result<()> {
         }))
         .unwrap();
     }
-    app().get_matches();
+    let mut app = app();
+    let matches = app.clone().get_matches();
+
+    // Simply print and exit if completion option is given.
+    if let Some(completion) = matches.value_of("completion") {
+        match completion {
+            "bash" => print_completions::<Bash>(&mut app),
+            "elvish" => print_completions::<Elvish>(&mut app),
+            "fish" => print_completions::<Fish>(&mut app),
+            "powershell" => print_completions::<PowerShell>(&mut app),
+            "zsh" => print_completions::<Zsh>(&mut app),
+            _ => println!("Unknown completion"), // Never reached
+        }
+
+        std::process::exit(0);
+    }
 
     let current_dir = env::current_dir().into_diagnostic()?;
     let mut git_config = Git2::try_from(current_dir)?;
